DSSocketIoWebSocketProvider class
Socket.IO WebSocket provider for DartStream.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
connect(
String url, {Map< String, dynamic> ? headers, Map<String, dynamic> ? options}) → Future<void> -
Connect to a WebSocket endpoint.
override
-
disconnect(
) → Future< void> -
Disconnect the provider.
override
-
dispose(
) → Future< void> -
Dispose of the provider and release resources.
override
-
emit(
String event, dynamic data) → void -
Emit an event with optional data.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
on(
String event, void handler(dynamic data)) → void -
Register an event listener.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited